PropertyKey

Trait PropertyKey 

pub trait PropertyKey {
    type Output: PropertyValue;

    // Required methods
    fn key(&self) -> CString;
    fn set(&self) -> PropertySet;

    // Provided method
    fn get(&self) -> Result<Self::Output> { ... }
}
Represents a TEE property key. The property key is used to identify a specific property within a property set. The property key is a string that is used to query the property value from the TEE property set. The property key is defined in the TEE Internal API, such as “gpd.client.identity” or “gpd.tee.apiversion”.

Required Associated Types

Required Methods

fn key(&self) -> CString

fn set(&self) -> PropertySet

Provided Methods

fn get(&self) -> Result<Self::Output>

Implementors

Source

impl PropertyKey for ClientEndian

Source

impl PropertyKey for ClientIdentity

Source

impl PropertyKey for TaAppId

Source

impl PropertyKey for TaDataSize

Source

impl PropertyKey for TaDescription

Source

impl PropertyKey for TaDoesNotCloseHandleOnCorruptObject

Source

impl PropertyKey for TaEndian

Source

impl PropertyKey for TaInstanceKeepAlive

Source

impl PropertyKey for TaInstanceKeepCrashed

Source

impl PropertyKey for TaMultiSession

Source

impl PropertyKey for TaSingleInstance

Source

impl PropertyKey for TaStackSize

Source

impl PropertyKey for TaVersion

Source

impl PropertyKey for TeeApiVersion

Source

impl PropertyKey for TeeArithMaxBigIntSize

Source

impl PropertyKey for TeeCryptographyBsiR

Source

impl PropertyKey for TeeCryptographyBsiT

Source

impl PropertyKey for TeeCryptographyEcc

Source

impl PropertyKey for TeeCryptographyIetf

Source

impl PropertyKey for TeeCryptographyNist

Source

impl PropertyKey for TeeCryptographyOcta

Source

impl PropertyKey for TeeDescription

Source

impl PropertyKey for TeeDeviceId

Source

impl PropertyKey for TeeEventMaxSources

Source

impl PropertyKey for TeeFirmwareImplementationBinaryVersion

Source

impl PropertyKey for TeeFirmwareImplementationVersion

Source

impl PropertyKey for TeeFirmwareManufacturer

Source

impl PropertyKey for TeeInternalCoreVersion

Source

impl PropertyKey for TeeSystemTimeProtectionLevel

Source

impl PropertyKey for TeeTaPersistentTimeProtectionLevel

Source

impl PropertyKey for TeeTrustedOsImplementationBinaryVersion

Source

impl PropertyKey for TeeTrustedOsImplementationVersion

Source

impl PropertyKey for TeeTrustedOsManufacturer

Source

impl PropertyKey for TeeTrustedStorageAntiRollbackProtectionLevel

Source

impl PropertyKey for TeeTrustedStoragePersoRollbackProtection

Source

impl PropertyKey for TeeTrustedStoragePrivateRollbackProtection

Source

impl PropertyKey for TeeTrustedStorageProtectedRollbackProtection

Source

impl PropertyKey for TeeTrustedStorageRollbackDetectionProtectionLevel